

from family_name import family_name
from boy import single_name, double_name
import random


def gen_name(length=1):
    if length == 1:
        return random.choice(family_name) + random.choice(single_name)
    elif length == 2:
        return random.choice(family_name) + random.choice(double_name)
    else:
        raise ValueError('暂不支持2字以上的名字!')

if __name__ == '__main__':
    a = gen_name()
    print(a)


from __future__ import print_function
from setuptools import setup, find_packages
import sys

setup(
    name="chinese_name",
    version="0.0.1",
    author="echo kang",
    author_email="528507274@qq.com",
    description="gen chinese name",
    long_description=open("README.md").read(),
    license="MIT",
    url="http://xx.com",
    packages=['src'],
    install_requires=[

    ],
    classifiers=[
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Topic :: Text Processing :: Indexing",
        "Topic :: Utilities",
        "Topic :: Internet",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
)